import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { csv, arc, pie, scaleBand, scaleLinear,max } from 'd3';

const csvUrl =
  'https://gist.githubusercontent.com/Ankit-Ian-53787/e8497617883547820729bf9e4293d02d/raw/a7d7beddf6a59ed46c33b3f453d39836005f8922/UNPopulation2019.csv';

const width = 960;
const height = 500;
const margin = {top:20,bottom:20,left:200,right:20};

const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row= d=>{
    d.Population = parseFloat(d['2020']);
    return d;
    };
    
    csv(csvUrl,row).then(data=>{
      setData(data.slice(0,10));
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }
  
  innerHeight = height - margin.top - margin.bottom;
  innerWidth = width - margin.left - margin.right;
  
  const yScale = scaleBand()
  .domain(data.map(d=>d.Country))
  .range([0,innerHeight]);
  
  const xScale = scaleLinear()
  .domain([0,max(data,d=>d.Population)])
  .range([0, innerWidth]);
  
  return (
    <svg width={width} height={height}>
      <g transform= {`translate(${margin.left},${margin.top})`}>
        {xScale.ticks().map(tickValue=>( 
          <g  transform= {`translate(${xScale(tickValue)},${0})`}>
          <line  
            y2={innerHeight} 
            stroke="black"/>
            <text style = {{textAnchor:'middle'}} dy=".7em" y={innerHeight+3} >{tickValue}</text>
            </g>
        ))}
      
        {yScale.domain().map(tickValue=>( 
            <text style = {{textAnchor:'end'}} dy=".32em" x="-3" y={yScale(tickValue)+yScale.bandwidth()/2}>{tickValue}</text>
           
        ))}
      
        
        {data.map( d => <rect x={0} y={yScale(d.Country)} width={xScale(d.Population)} height={yScale.bandwidth()} />)} 
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);

// To compute the arcs manually (without d3.pie):
// data.map((d, i) => (
//   <path
//     fill={d['RGB hex value']}
//     d={pieArc({
//       startAngle: (i / data.length) * 2 * Math.PI,
//       endAngle: ((i + 1) / data.length) * 2 * Math.PI
//     })}
//   />
// ))
